@@ -2,13 +2,13 @@
 
 package Validation::Class;
 {
-    $Validation::Class::VERSION = '7.55';
+    $Validation::Class::VERSION = '7.58';
 }
 
 use strict;
 use warnings;
 
-our $VERSION = '7.55';    # VERSION
+our $VERSION = '7.58';    # VERSION
 
 use Module::Find;
 use Carp 'confess';
@@ -395,6 +395,7 @@ sub load {
             foreach my $parent (@parents) {
 
                 # load class children and create relationship map (hash)
+
                 foreach my $child (findallmod $parent) {
 
                     my $nickname = $child;
@@ -438,7 +439,7 @@ sub load {
 
             }
 
-            $proto->{config}->{PLUGINS}->{$_} = 1 for @plugins;
+            $proto->{config}->{PLUGINS}->{$_} = undef for @plugins;
 
         }
 
@@ -710,7 +711,8 @@ sub new {
 
     foreach my $plugin (keys %{$config->{PLUGINS}}) {
 
-        $plugin->new($self) if $plugin->can('new');
+        $proto->plugins->{$plugin} = $plugin->new($self)
+          if $plugin->can('new');
 
     }
 
@@ -840,7 +842,7 @@ Validation::Class - Self-Validating Object System and Data Validation Framework
 
 =head1 VERSION
 
-version 7.55
+version 7.58
 
 =head1 SYNOPSIS
 
@@ -1125,7 +1127,9 @@ class mainly involve copying the role's methods and configuration.
     # load stuff (extend MyApp)
     
     load {
-        ...
+        
+        # run package commands
+        
     };
     
     1;
@@ -1208,11 +1212,10 @@ executing load/set commands, the syntax is as follows:
     
     load roles => ['MyVal::Person'];
     load classes => [__PACKAGE__];
-    
     load plugins => [
         'CPANPlugin', # Validation::Class::Plugin::CPANPlugin
         '+MyVal::Plugin'
-    ];
+    ];    
 
 =head2 method
 
@@ -1634,6 +1637,12 @@ See L<Validation::Class::Prototype/param> for full documentation.
 
 See L<Validation::Class::Prototype/params> for full documentation.
 
+=head2 plugin
+
+    $self->plugin;
+
+See L<Validation::Class::Prototype/plugin> for full documentation.
+
 =head2 queue
 
     $self->queue;
