@@ -2,13 +2,13 @@
 
 package Validation::Class::Prototype;
 {
-    $Validation::Class::Prototype::VERSION = '7.55';
+    $Validation::Class::Prototype::VERSION = '7.58';
 }
 
 use strict;
 use warnings;
 
-our $VERSION = '7.55';    # VERSION
+our $VERSION = '7.58';    # VERSION
 
 use base 'Validation::Class::Backwards';    # I'm pro-life
 
@@ -84,7 +84,7 @@ hold 'mixins' => sub { {} };
 hold 'params' => sub { {} };
 
 
-has plugins => sub { shift->{config}->{PLUGINS} || {} };
+has plugins => sub { {} };
 
 
 hold 'profiles' => sub { {} };
@@ -1972,6 +1972,36 @@ sub pitch_error {
 
 }
 
+
+sub plugin {
+
+    my ($self, $class) = @_;
+
+    return 0 unless $class;
+
+    # transform what looks like a shortname
+
+    if ($class !~ /::/) {
+
+        my @parts = split /[^0-9A-Za-z_]/, $class;
+
+        foreach my $part (@parts) {
+
+            $part = ucfirst $part;
+            $part =~ s/([a-z])_([a-z])/$1\u$2/g;
+
+        }
+
+        !$parts[0] ? shift @parts : push @parts, 'Validation::Class::Plugin';
+
+        $class = join "::", @parts;
+
+    }
+
+    return $self->plugins->{$class};
+
+}
+
 sub proxy_methods {
 
     return qw{
@@ -1993,6 +2023,7 @@ sub proxy_methods {
       ignore_unknown
       param
       params
+      plugin
       queue
       report_failure
       report_unknown
@@ -2809,7 +2840,7 @@ Validation::Class::Prototype - Prototype and Data Validation Engine for Validati
 
 =head1 VERSION
 
-version 7.55
+version 7.58
 
 =head1 SYNOPSIS
 
@@ -3100,11 +3131,12 @@ prefixed with the name of the class being fetched, and adjust the matching rule
     my $child3  = $input->class('child');      # loads Class::Child;
     my $child4  = $input->class('step_child'); # loads Class::StepChild;
     
-    # use any non-alpha character except for underscore to split the namespace
+    # use any non-alphanumeric character or underscore as the namespace delimiter
     
-    my $child5  = $input->class('step-child'); # loads Class::Step::Child;
+    my $child5  = $input->class('step/child'); # loads Class::Step::Child;
     my $child5a = $input->class('step:child'); # loads Class::Step::Child;
     my $child5b = $input->class('step.child'); # loads Class::Step::Child;
+    my $child5c = $input->class('step-child'); # loads Class::Step::Child;
     
     my $child6  = $input->class('CHILD');      # loads Class::CHILD;
     
@@ -3319,6 +3351,36 @@ value assigned or undefined if the parameter does not exist.
     
     $self->param($name => $value);
 
+=head2 plugin
+
+The plugin method returns the instantiated plugin object attached to the current
+class.
+
+    package Class;
+    
+    use Validation::Class;
+    
+    load plugin => ['TelephoneFormat'];
+    load plugin => ['+Class::Plugin::Form::Elements'];
+    
+    package main;
+    
+    my $input = Class->new(params => $params);
+    
+    # get object for Validation::Class::Plugin::TelephoneFormat;
+    
+    my $plugin = $input->plugin('telephone_format');
+    
+    # use any non-alphanumeric character or underscore as the namespace delimiter
+    # get object for Class::Plugin::Form::Elements;
+    # note the leading character/delimiter
+    
+    my $plugin = $input->plugin(':class:plugin:form:elements'); 
+    
+    # same as $input->proto->plugins->{'Class::Plugin::Form::Elements'};
+    
+    my $plugin = $input->plugin('Class::Plugin::Form::Elements');
+
 =head2 queue
 
 The queue method is a convenience method used specifically to append the
